==> tsd-0.2.0.tgz: package/src/tsd.ts <==
///<reference path='d.ts/node-0.8.d.ts'/>
///<reference path='System/Console.ts'/>
///<reference path='System/IO/FileManager.ts'/>
///<reference path='System/Web/WebHandler.ts'/>

///<reference path='CommandLineProcessor.ts'/>
///<reference path='Config.ts'/>
///<reference path='DataSource\DataSourceFactory.ts'/>

var VERSION = "0.1.2";

class Main { 
    public init() { 
        System.Console.initialize();
        System.IO.FileManager.initialize();
        System.IO.DirectoryManager.initialize();
        System.Web.WebHandler.initialize();
    }

    public run(args: Array) { 

        try { 
            var cfg = new Config();

            cfg.repositoryType = RepositoryTypeEnum.Web;
            cfg.uri = "https://github.com/Diullei/tsd/raw/master/deploy/repository.json";

            //cfg.repositoryType = RepositoryTypeEnum.FileSystem;
            //cfg.uri = "C:\\Users\\dgomes\\Documents\\GitHub\\tsd\\deploy\\repository.json";

            cfg.localPath = "d.ts";

            var ds = DataSource.DataSourceFactory.factory(cfg);
            var cp = new CommandLineProcessor(ds, cfg);
            cp.execute(args);
        } catch(e){
            System.Console.writeLine(e.message);
        }
    }
}

var main = new Main();
main.init();

var arguments: Array;

if (System.Environment.isNode()) {
    arguments = Array.prototype.slice.call(process.argv);
} if (System.Environment.isWsh()) {
    var args = [null, null];
    for (var i = 0; i < WScript.Arguments.length; i++) {
        args[2 + i] = WScript.Arguments.Item(i);
    }
    arguments = <Array><any>args;
}

main.run(arguments);

==> tsd-0.2.2.tgz: package/src/tsd.ts <==
///<reference path='d.ts/node-0.8.d.ts'/>
///<reference path='System/Console.ts'/>
///<reference path='System/IO/FileManager.ts'/>
///<reference path='System/Web/WebHandler.ts'/>

///<reference path='CommandLineProcessor.ts'/>
///<reference path='Config.ts'/>
///<reference path='DataSource\DataSourceFactory.ts'/>

var VERSION = "0.2.1";

class Main { 
    public init() { 
        System.Console.initialize();
        System.IO.FileManager.initialize();
        System.IO.DirectoryManager.initialize();
        System.Web.WebHandler.initialize();
    }

    public run(args: Array) { 

        try { 
            var cfg = new Config();

            cfg.repositoryType = RepositoryTypeEnum.Web;
            cfg.uri = "https://github.com/Diullei/tsd/raw/master/deploy/repository.json";

            //cfg.repositoryType = RepositoryTypeEnum.FileSystem;
            //cfg.uri = "repository.json";

            cfg.localPath = "d.ts";

            var ds = DataSource.DataSourceFactory.factory(cfg);
            var cp = new CommandLineProcessor(ds, cfg);
            cp.execute(args);
        } catch(e){
            System.Console.writeLine(e.message);
        }
    }
}

var main = new Main();
main.init();

var arguments: Array;

if (System.Environment.isNode()) {
    arguments = Array.prototype.slice.call(process.argv);
} if (System.Environment.isWsh()) {
    var args = [null, null];
    for (var i = 0; i < WScript.Arguments.length; i++) {
        args[2 + i] = WScript.Arguments.Item(i);
    }
    arguments = <Array><any>args;
}

main.run(arguments);
